@@ -48,16 +48,16 @@ Cantor::Session* MaximaBackend::createSession()
 
 Cantor::Backend::Capabilities MaximaBackend::capabilities() const
 {
-    Cantor::Backend::Capabilities cap =
+    static Cantor::Backend::Capabilities cap =
         Cantor::Backend::LaTexOutput |
         Cantor::Backend::InteractiveMode|
         Cantor::Backend::SyntaxHighlighting|
         Cantor::Backend::Completion |
         Cantor::Backend::SyntaxHelp;
     if(MaximaSettings::self()->variableManagement())
-        cap |= Cantor::Backend::VariableManagement;
-
-    return cap;
+        return cap |= Cantor::Backend::VariableManagement;
+    else
+        return cap;
 }
 
 bool MaximaBackend::requirementsFullfilled(QString* const reason) const
